==> hyakutyping-0.0.4.tar.gz: hyakutyping-0.0.4/src/hyakutypingrc_orig.h <==
#ifndef HYAKUTYPINGRC_ORIG_H
#define HYAKUTYPINGRC_ORIG_H

/*!
  \file
  \brief Resource (hyakutypingrc_orig)

  \author Satofumi KAMIMURA

  $Id$
*/

static const unsigned char hyakutypingrc_orig[] = {
  0x23,0x20,0x81,0x75,0x95,0x53,0x90,0x6c,0x88,0xea,0x8e,0xf1,0x83,0x5e,0x83,
  0x43,0x83,0x73,0x83,0x93,0x83,0x4f,0x81,0x76,0x90,0xdd,0x92,0xe8,0x82,0xcc,
  0x8f,0x89,0x8a,0xfa,0x83,0x74,0x83,0x40,0x83,0x43,0x83,0x8b,0x0d,0x0a,0x0d,
  0x0a,0x23,0x20,0x83,0x56,0x83,0x58,0x83,0x65,0x83,0x80,0x90,0xdd,0x92,0xe8,
  0x0d,0x0a,0x65,0x66,0x66,0x65,0x63,0x74,0x5f,0x64,0x65,0x63,0x69,0x64,0x65,
  0x20,0x3d,0x20,0x22,0x64,0x65,0x63,0x69,0x64,0x65,0x2e,0x77,0x61,0x76,0x22,
  0x0d,0x0a,0x65,0x66,0x66,0x65,0x63,0x74,0x5f,0x74,0x79,0x70,0x65,0x20,0x3d,
  0x20,0x22,0x74,0x79,0x70,0x65,0x2e,0x77,0x61,0x76,0x22,0x0d,0x0a,0x65,0x66,
  0x66,0x65,0x63,0x74,0x5f,0x6d,0x69,0x73,0x73,0x20,0x3d,0x20,0x22,0x6d,0x69,
  0x73,0x73,0x2e,0x77,0x61,0x76,0x22,0x0d,0x0a,0x0d,0x0a,0x23,0x20,0x89,0xb9,
  0x97,0xca,0x0d,0x0a,0x23,0x20,0x21,0x21,0x21,0x0d,0x0a,0x0d,0x0a,0x23,0x23,
  0x23,0x23,0x23,0x20,0x83,0x86,0x81,0x5b,0x83,0x55,0x88,0xea,0x97,0x97,0x20,
  0x23,0x23,0x23,0x23,0x23,0x0d,0x0a,0x0d,0x0a,0x23,0x20,0x83,0x86,0x81,0x5b,
  0x83,0x55,0x88,0xea,0x97,0x97,0x0d,0x0a,0x75,0x5f,0x30,0x30,0x20,0x3d,0x20,
  0x22,0x67,0x75,0x65,0x73,0x74,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x31,0x20,0x3d,
  0x20,0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x32,0x20,0x3d,0x20,0x22,0x22,0x0d,
  0x0a,0x75,0x5f,0x30,0x33,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,
  0x34,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x0d,0x0a,0x23,0x20,0x8f,0x89,0x8a,
  0xfa,0x91,0x49,0x91,0xf0,0x82,0xcc,0x83,0x86,0x81,0x5b,0x83,0x55,0x20,0x49,
  0x44,0x0d,0x0a,0x75,0x5f,0x69,0x6e,0x64,0x65,0x78,0x20,0x3d,0x20,0x22,0x30,
  0x22,0x0d,0x0a,0x0d,0x0a,0x0d,0x0a,0x23,0x23,0x23,0x23,0x23,0x20,0x83,0x86,
  0x81,0x5b,0x83,0x55,0x96,0x88,0x82,0xcc,0x90,0xdd,0x92,0xe8,0x20,0x23,0x23,
  0x23,0x23,0x23,0x0d,0x0a,0x0d,0x0a,0x23,0x20,0x93,0x6f,0x98,0x5e,0x83,0x41,
  0x83,0x68,0x83,0x8c,0x83,0x58,0x0d,0x0a,0x75,0x5f,0x30,0x30,0x5f,0x68,0x74,
  0x74,0x70,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x31,0x5f,0x68,
  0x74,0x74,0x70,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x32,0x5f,
  0x68,0x74,0x74,0x70,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x33,
  0x5f,0x68,0x74,0x74,0x70,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,
  0x34,0x5f,0x68,0x74,0x74,0x70,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x0d,0x0a,
  0x23,0x20,0x83,0x70,0x83,0x58,0x83,0x8f,0x81,0x5b,0x83,0x68,0x0d,0x0a,0x75,
  0x5f,0x30,0x30,0x5f,0x70,0x61,0x73,0x73,0x77,0x6f,0x72,0x64,0x20,0x3d,0x20,
  0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x31,0x5f,0x70,0x61,0x73,0x73,0x77,0x6f,
  0x72,0x64,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x32,0x5f,0x70,
  0x61,0x73,0x73,0x77,0x6f,0x72,0x64,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x75,
  0x5f,0x30,0x33,0x5f,0x70,0x61,0x73,0x73,0x77,0x6f,0x72,0x64,0x20,0x3d,0x20,
  0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x34,0x5f,0x70,0x61,0x73,0x73,0x77,0x6f,
  0x72,0x64,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x0d,0x0a,0x23,0x20,0x93,0xfc,
  0x97,0xcd,0x83,0x82,0x81,0x5b,0x83,0x68,0x0d,0x0a,0x23,0x20,0x83,0x8d,0x81,
  0x5b,0x83,0x7d,0x8e,0x9a,0x93,0xfc,0x97,0xcd,0x3a,0x72,0x6f,0x6d,0x61,0x6e,
  0x20,0x2f,0x20,0x82,0xa9,0x82,0xc8,0x93,0xfc,0x97,0xcd,0x3a,0x6b,0x61,0x6e,
  0x61,0x0d,0x0a,0x75,0x5f,0x30,0x30,0x5f,0x63,0x6f,0x6e,0x76,0x65,0x72,0x74,
  0x65,0x72,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x31,0x5f,0x63,
  0x6f,0x6e,0x76,0x65,0x72,0x74,0x65,0x72,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,
  0x75,0x5f,0x30,0x32,0x5f,0x63,0x6f,0x6e,0x76,0x65,0x72,0x74,0x65,0x72,0x20,
  0x3d,0x20,0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x33,0x5f,0x63,0x6f,0x6e,0x76,
  0x65,0x72,0x74,0x65,0x72,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,
  0x34,0x5f,0x63,0x6f,0x6e,0x76,0x65,0x72,0x74,0x65,0x72,0x20,0x3d,0x20,0x22,
  0x22,0x0d,0x0a,0x0d,0x0a,0x23,0x20,0x97,0xfb,0x8f,0x4b,0x90,0x94,0x0d,0x0a,
  0x23,0x20,0x98,0x61,0x89,0xcc,0x82,0xcc,0x97,0xfb,0x8f,0x4b,0x90,0x94,0x0d,
  0x0a,0x75,0x5f,0x30,0x30,0x5f,0x74,0x6f,0x74,0x61,0x6c,0x20,0x3d,0x20,0x22,
  0x22,0x0d,0x0a,0x75,0x5f,0x30,0x31,0x5f,0x74,0x6f,0x74,0x61,0x6c,0x20,0x3d,
  0x20,0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x32,0x5f,0x74,0x6f,0x74,0x61,0x6c,
  0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x33,0x5f,0x74,0x6f,0x74,
  0x61,0x6c,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x34,0x5f,0x74,
  0x6f,0x74,0x61,0x6c,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x0d,0x0a,0x23,0x20,
  0x89,0xe6,0x96,0xca,0x90,0xdd,0x92,0xe8,0x0d,0x0a,0x23,0x20,0x83,0x74,0x83,
  0x8b,0x83,0x58,0x83,0x4e,0x83,0x8a,0x81,0x5b,0x83,0x93,0x3a,0x31,0x20,0x2f,
  0x20,0x92,0xca,0x8f,0xed,0x83,0x58,0x83,0x4e,0x83,0x8a,0x81,0x5b,0x83,0x93,
  0x3a,0x30,0x0d,0x0a,0x23,0x20,0x21,0x21,0x21,0x0d,0x0a,0x0d,0x0a,0x23,0x20,
  0x8f,0x64,0x93,0x5f,0x97,0xfb,0x8f,0x4b,0x83,0x82,0x81,0x5b,0x83,0x68,0x20,
  0x28,0x93,0xfc,0x97,0xcd,0x8a,0x4a,0x8e,0x6e,0x82,0xaa,0x91,0x81,0x82,0xad,
  0x82,0xc8,0x82,0xe9,0x82,0xdc,0x82,0xc5,0x81,0x41,0x93,0xaf,0x82,0xb6,0x98,
  0x61,0x89,0xcc,0x82,0xaa,0x96,0x88,0x89,0xf1,0x95,0x5c,0x8e,0xa6,0x82,0xb3,
  0x82,0xea,0x82,0xe9,0x29,0x0d,0x0a,0x23,0x20,0x8f,0x64,0x93,0x5f,0x97,0xfb,
  0x8f,0x4b,0x82,0xb5,0x82,0xc8,0x82,0xa2,0x3a,0x2d,0x31,0x20,0x2f,0x20,0x3e,
  0x3d,0x20,0x30,0x20,0x8f,0x64,0x93,0x5f,0x97,0xfb,0x8f,0x4b,0x92,0x86,0x82,
  0xcc,0x98,0x61,0x89,0xcc,0x82,0xcc,0x94,0xd4,0x8d,0x86,0x0d,0x0a,0x23,0x20,
  0x21,0x21,0x21,0x0d,0x0a,0x0d,0x0a,0x23,0x20,0x89,0x72,0x82,0xdd,0x8f,0xe3,
  0x82,0xb0,0x90,0xdd,0x92,0xe8,0x0d,0x0a,0x23,0x20,0x21,0x21,0x21,0x0d,0x0a,
};

#endif /* !HYAKUTYPINGRC_ORIG_H */

==> hyakutyping-0.0.5.tar.gz: hyakutyping-0.0.5/src/hyakutypingrc_orig.h <==
#ifndef HYAKUTYPINGRC_ORIG_H
#define HYAKUTYPINGRC_ORIG_H

/*!
  \file
  \brief Resource (hyakutypingrc_orig)

  \author Satofumi KAMIMURA

  $Id$
*/

static const unsigned char hyakutypingrc_orig[] = {
  0x23,0x20,0x81,0x75,0x95,0x53,0x90,0x6c,0x88,0xea,0x8e,0xf1,0x83,0x5e,0x83,
  0x43,0x83,0x73,0x83,0x93,0x83,0x4f,0x81,0x76,0x90,0xdd,0x92,0xe8,0x82,0xcc,
  0x8f,0x89,0x8a,0xfa,0x83,0x74,0x83,0x40,0x83,0x43,0x83,0x8b,0x0d,0x0a,0x0d,
  0x0a,0x23,0x20,0x83,0x56,0x83,0x58,0x83,0x65,0x83,0x80,0x90,0xdd,0x92,0xe8,
  0x0d,0x0a,0x65,0x66,0x66,0x65,0x63,0x74,0x5f,0x64,0x65,0x63,0x69,0x64,0x65,
  0x20,0x3d,0x20,0x22,0x64,0x65,0x63,0x69,0x64,0x65,0x2e,0x77,0x61,0x76,0x22,
  0x0d,0x0a,0x65,0x66,0x66,0x65,0x63,0x74,0x5f,0x74,0x79,0x70,0x65,0x20,0x3d,
  0x20,0x22,0x74,0x79,0x70,0x65,0x2e,0x77,0x61,0x76,0x22,0x0d,0x0a,0x65,0x66,
  0x66,0x65,0x63,0x74,0x5f,0x6d,0x69,0x73,0x73,0x20,0x3d,0x20,0x22,0x6d,0x69,
  0x73,0x73,0x2e,0x77,0x61,0x76,0x22,0x0d,0x0a,0x0d,0x0a,0x23,0x20,0x89,0xb9,
  0x97,0xca,0x0d,0x0a,0x23,0x20,0x21,0x21,0x21,0x0d,0x0a,0x0d,0x0a,0x23,0x23,
  0x23,0x23,0x23,0x20,0x83,0x86,0x81,0x5b,0x83,0x55,0x88,0xea,0x97,0x97,0x20,
  0x23,0x23,0x23,0x23,0x23,0x0d,0x0a,0x0d,0x0a,0x23,0x20,0x83,0x86,0x81,0x5b,
  0x83,0x55,0x88,0xea,0x97,0x97,0x0d,0x0a,0x75,0x5f,0x30,0x30,0x20,0x3d,0x20,
  0x22,0x67,0x75,0x65,0x73,0x74,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x31,0x20,0x3d,
  0x20,0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x32,0x20,0x3d,0x20,0x22,0x22,0x0d,
  0x0a,0x75,0x5f,0x30,0x33,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,
  0x34,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x0d,0x0a,0x23,0x20,0x8f,0x89,0x8a,
  0xfa,0x91,0x49,0x91,0xf0,0x82,0xcc,0x83,0x86,0x81,0x5b,0x83,0x55,0x20,0x49,
  0x44,0x0d,0x0a,0x75,0x5f,0x69,0x6e,0x64,0x65,0x78,0x20,0x3d,0x20,0x22,0x30,
  0x22,0x0d,0x0a,0x0d,0x0a,0x0d,0x0a,0x23,0x23,0x23,0x23,0x23,0x20,0x83,0x86,
  0x81,0x5b,0x83,0x55,0x96,0x88,0x82,0xcc,0x90,0xdd,0x92,0xe8,0x20,0x23,0x23,
  0x23,0x23,0x23,0x0d,0x0a,0x0d,0x0a,0x23,0x20,0x93,0x6f,0x98,0x5e,0x83,0x41,
  0x83,0x68,0x83,0x8c,0x83,0x58,0x0d,0x0a,0x75,0x5f,0x30,0x30,0x5f,0x68,0x74,
  0x74,0x70,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x31,0x5f,0x68,
  0x74,0x74,0x70,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x32,0x5f,
  0x68,0x74,0x74,0x70,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x33,
  0x5f,0x68,0x74,0x74,0x70,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,
  0x34,0x5f,0x68,0x74,0x74,0x70,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x0d,0x0a,
  0x23,0x20,0x83,0x70,0x83,0x58,0x83,0x8f,0x81,0x5b,0x83,0x68,0x0d,0x0a,0x75,
  0x5f,0x30,0x30,0x5f,0x70,0x61,0x73,0x73,0x77,0x6f,0x72,0x64,0x20,0x3d,0x20,
  0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x31,0x5f,0x70,0x61,0x73,0x73,0x77,0x6f,
  0x72,0x64,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x32,0x5f,0x70,
  0x61,0x73,0x73,0x77,0x6f,0x72,0x64,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x75,
  0x5f,0x30,0x33,0x5f,0x70,0x61,0x73,0x73,0x77,0x6f,0x72,0x64,0x20,0x3d,0x20,
  0x22,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x34,0x5f,0x70,0x61,0x73,0x73,0x77,0x6f,
  0x72,0x64,0x20,0x3d,0x20,0x22,0x22,0x0d,0x0a,0x0d,0x0a,0x23,0x20,0x93,0xfc,
  0x97,0xcd,0x83,0x82,0x81,0x5b,0x83,0x68,0x0d,0x0a,0x23,0x20,0x83,0x8d,0x81,
  0x5b,0x83,0x7d,0x8e,0x9a,0x93,0xfc,0x97,0xcd,0x3a,0x30,0x20,0x2f,0x20,0x82,
  0xa9,0x82,0xc8,0x93,0xfc,0x97,0xcd,0x3a,0x31,0x0d,0x0a,0x75,0x5f,0x30,0x30,
  0x5f,0x63,0x6f,0x6e,0x76,0x65,0x72,0x74,0x65,0x72,0x20,0x3d,0x20,0x22,0x30,
  0x22,0x0d,0x0a,0x75,0x5f,0x30,0x31,0x5f,0x63,0x6f,0x6e,0x76,0x65,0x72,0x74,
  0x65,0x72,0x20,0x3d,0x20,0x22,0x30,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x32,0x5f,
  0x63,0x6f,0x6e,0x76,0x65,0x72,0x74,0x65,0x72,0x20,0x3d,0x20,0x22,0x30,0x22,
  0x0d,0x0a,0x75,0x5f,0x30,0x33,0x5f,0x63,0x6f,0x6e,0x76,0x65,0x72,0x74,0x65,
  0x72,0x20,0x3d,0x20,0x22,0x30,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x34,0x5f,0x63,
  0x6f,0x6e,0x76,0x65,0x72,0x74,0x65,0x72,0x20,0x3d,0x20,0x22,0x30,0x22,0x0d,
  0x0a,0x0d,0x0a,0x23,0x20,0x98,0x61,0x89,0xcc,0x82,0xcc,0x97,0xfb,0x8f,0x4b,
  0x90,0x94,0x0d,0x0a,0x75,0x5f,0x30,0x30,0x5f,0x6e,0x75,0x6d,0x20,0x3d,0x20,
  0x22,0x35,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x31,0x5f,0x6e,0x75,0x6d,0x20,0x3d,
  0x20,0x22,0x35,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x32,0x5f,0x6e,0x75,0x6d,0x20,
  0x3d,0x20,0x22,0x35,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x33,0x5f,0x6e,0x75,0x6d,
  0x20,0x3d,0x20,0x22,0x35,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x34,0x5f,0x6e,0x75,
  0x6d,0x20,0x3d,0x20,0x22,0x35,0x22,0x0d,0x0a,0x0d,0x0a,0x23,0x20,0x8b,0xc8,
  0x82,0xcc,0x89,0xb9,0x97,0xca,0x0d,0x0a,0x75,0x5f,0x30,0x30,0x5f,0x6d,0x75,
  0x73,0x69,0x63,0x20,0x3d,0x20,0x22,0x37,0x35,0x22,0x0d,0x0a,0x75,0x5f,0x30,
  0x31,0x5f,0x6d,0x75,0x73,0x69,0x63,0x20,0x3d,0x20,0x22,0x37,0x35,0x22,0x0d,
  0x0a,0x75,0x5f,0x30,0x32,0x5f,0x6d,0x75,0x73,0x69,0x63,0x20,0x3d,0x20,0x22,
  0x37,0x35,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x33,0x5f,0x6d,0x75,0x73,0x69,0x63,
  0x20,0x3d,0x20,0x22,0x37,0x35,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x34,0x5f,0x6d,
  0x75,0x73,0x69,0x63,0x20,0x3d,0x20,0x22,0x37,0x35,0x22,0x0d,0x0a,0x0d,0x0a,
  0x23,0x20,0x8c,0xf8,0x89,0xca,0x89,0xb9,0x82,0xcc,0x89,0xb9,0x97,0xca,0x0d,
  0x0a,0x75,0x5f,0x30,0x30,0x5f,0x65,0x66,0x66,0x65,0x63,0x74,0x20,0x3d,0x20,
  0x22,0x37,0x35,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x31,0x5f,0x65,0x66,0x66,0x65,
  0x63,0x74,0x20,0x3d,0x20,0x22,0x37,0x35,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x32,
  0x5f,0x65,0x66,0x66,0x65,0x63,0x74,0x20,0x3d,0x20,0x22,0x37,0x35,0x22,0x0d,
  0x0a,0x75,0x5f,0x30,0x33,0x5f,0x65,0x66,0x66,0x65,0x63,0x74,0x20,0x3d,0x20,
  0x22,0x37,0x35,0x22,0x0d,0x0a,0x75,0x5f,0x30,0x34,0x5f,0x65,0x66,0x66,0x65,
  0x63,0x74,0x20,0x3d,0x20,0x22,0x37,0x35,0x22,0x0d,0x0a,0x0d,0x0a,0x23,0x20,
  0x89,0xe6,0x96,0xca,0x90,0xdd,0x92,0xe8,0x0d,0x0a,0x23,0x20,0x83,0x74,0x83,
  0x8b,0x83,0x58,0x83,0x4e,0x83,0x8a,0x81,0x5b,0x83,0x93,0x3a,0x31,0x20,0x2f,
  0x20,0x92,0xca,0x8f,0xed,0x83,0x58,0x83,0x4e,0x83,0x8a,0x81,0x5b,0x83,0x93,
  0x3a,0x30,0x0d,0x0a,0x23,0x20,0x21,0x21,0x21,0x0d,0x0a,0x0d,0x0a,0x23,0x20,
  0x8f,0x64,0x93,0x5f,0x97,0xfb,0x8f,0x4b,0x83,0x82,0x81,0x5b,0x83,0x68,0x20,
  0x28,0x93,0xfc,0x97,0xcd,0x8a,0x4a,0x8e,0x6e,0x82,0xaa,0x91,0x81,0x82,0xad,
  0x82,0xc8,0x82,0xe9,0x82,0xdc,0x82,0xc5,0x81,0x41,0x93,0xaf,0x82,0xb6,0x98,
  0x61,0x89,0xcc,0x82,0xaa,0x96,0x88,0x89,0xf1,0x95,0x5c,0x8e,0xa6,0x82,0xb3,
  0x82,0xea,0x82,0xe9,0x29,0x0d,0x0a,0x23,0x20,0x8f,0x64,0x93,0x5f,0x97,0xfb,
  0x8f,0x4b,0x82,0xb5,0x82,0xc8,0x82,0xa2,0x3a,0x2d,0x31,0x20,0x2f,0x20,0x3e,
  0x3d,0x20,0x30,0x20,0x8f,0x64,0x93,0x5f,0x97,0xfb,0x8f,0x4b,0x92,0x86,0x82,
  0xcc,0x98,0x61,0x89,0xcc,0x82,0xcc,0x94,0xd4,0x8d,0x86,0x0d,0x0a,0x23,0x20,
  0x21,0x21,0x21,0x0d,0x0a,0x0d,0x0a,0x23,0x20,0x89,0x72,0x82,0xdd,0x8f,0xe3,
  0x82,0xb0,0x90,0xdd,0x92,0xe8,0x0d,0x0a,0x23,0x20,0x21,0x21,0x21,0x0d,0x0a,
};

#endif /* !HYAKUTYPINGRC_ORIG_H */
